@@ -14,7 +14,7 @@
 #                                                                     #
 #######################################################################
 
-record<-function(input.seq, times=10, LOD=0, max.rf=0.5){
+record<-function(input.seq, times=10, LOD=0, max.rf=0.5, tol=10E-5){
   ## checking for correct object
   if(!any(class(input.seq)=="sequence")) stop(deparse(substitute(input.seq))," is
     not an object of class 'sequence'")
@@ -127,15 +127,15 @@ record<-function(input.seq, times=10, LOD=0, max.rf=0.5){
           }
         }
       }
-      if(COUNT(X,result.new)>COUNT(X,result)){
+      if(COUNT(X,result.new) > COUNT(X,result)){
         result.new<-result
-        ##print(COUNT(X,result))
+        ##print(COUNT(X,result.new))
       }
     }
   }
   ## end of RECORD algorithm
- cat("\norder obtained using RECORD algorithm:\n\n", input.seq$seq.num[avoid.reverse(result.new)], "\n\ncalculating multipoint map using tol = 10E-5.\n\n")
-  map(make.seq(get(input.seq$twopt),input.seq$seq.num[avoid.reverse(result.new)],twopt=input.seq$twopt), tol=10E-5)
+ cat("\norder obtained using RECORD algorithm:\n\n", input.seq$seq.num[avoid.reverse(result.new)], "\n\ncalculating multipoint map using tol", tol, ".\n\n")
+  map(make.seq(get(input.seq$twopt),input.seq$seq.num[avoid.reverse(result.new)],twopt=input.seq$twopt), tol=tol)
 }
 
 ##end of file
